import 'dart:ui';

import 'package:flutter/material.dart';
import 'package:notar_e_anotar_app/styles/global_styles.dart';

class WeekdayTile extends StatefulWidget {
  final int dayNumber;
  final String dayName;
  final bool isLast;
  final bool isToday;
  final Function callback;

  WeekdayTile(
      {this.dayNumber, this.dayName, this.isLast, this.isToday, this.callback});

  @override
  _WeekdayTileState createState() => _WeekdayTileState();
}

class _WeekdayTileState extends State<WeekdayTile> {
  int dayNumber;
  String dayName;
  bool isLast;
  bool isToday;
  Function callback;

  void changeDay() {
    setState(() {
      this.callback(dayNumber - 1);
      this.isToday = this.isToday ? false : true;
    });
  }

  @override
  void initState() {
    super.initState();
    this.dayNumber = widget.dayNumber;
    this.dayName = widget.dayName;
    this.isLast = widget.isLast;
    this.isToday = widget.isToday;
    this.callback = widget.callback;
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      clipBehavior: Clip.none,
      margin: EdgeInsets.only(right: isLast ? 0 : 4),
      decoration: BoxDecoration(
          color: isToday ? primary : Colors.transparent,
          borderRadius: BorderRadiusDirectional.all(Radius.circular(8))),
      child: ElevatedButton(
        style: ButtonStyle(
          shape: MaterialStateProperty.all(
              RoundedRectangleBorder(borderRadius: BorderRadius.circular(8))),
          backgroundColor: MaterialStateProperty.all(Colors.transparent),
          elevation: MaterialStateProperty.resolveWith((states) {
            if (states.contains(MaterialState.pressed)) {
              return 3.0;
            } else {
              return 0.0;
            }
          }),
        ),
        onPressed: () => changeDay(),
        child: Padding(
          padding: EdgeInsets.symmetric(vertical: 10, horizontal: 0),
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: [
              Text(
                '$dayNumber',
                style: isToday
                    ? Theme.of(context)
                        .textTheme
                        .bodyText1
                        .copyWith(height: 1.3)
                    : Theme.of(context)
                        .textTheme
                        .bodyText1
                        .copyWith(height: 1.3, color: primaryAccent),
              ),
              Text(
                '$dayName',
                style: isToday
                    ? Theme.of(context).textTheme.bodyText2
                    : Theme.of(context)
                        .textTheme
                        .bodyText2
                        .copyWith(color: primaryAccent),
              )
            ],
          ),
        ),
      ),
    );
  }
}
